(failure cmds-and-traces state bindings)Return a vector of [handle failure] representing which command failed, and why. Returns nil if no command has failed.
The failure entry is a map with a :message key and an optional :events key, which contains clojure.test report events of type :error and :fail that were emitted during the evaluation of the postcondition.
Return a vector of [handle failure] representing which command failed, and why. Returns nil if no command has failed. The failure entry is a map with a :message key and an optional :events key, which contains clojure.test report events of type :error and :fail that were emitted during the evaluation of the postcondition.
(runners->results {:keys [sequential parallel]}
bindings
timeout-ms
assume-immutable-results)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |